@@ -5,7 +5,7 @@ from hautomation_x10 import settings
 class ControlForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         super(ControlForm, self).__init__(*args, **kwargs)
-        self.fields["protocol"] = forms.ChoiceField(choices=["GPIO", "X10"])
+        self.fields["protocol"] = forms.ChoiceField(choices=[("GPIO", "GPIO"), ("X10", "X10")])
 
         self.fields["protocol"].widget.attrs = {"class": "span3"}
         self.fields["did"].widget.attrs = {"class": "span4"}
